#
# spec file for package libretro-picodrive
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libretro-picodrive
Version:        0~git20210611
Release:        150500.1.pm.4
Summary:        PicoDrive libretro core for MegaDrive/Genesis emulation
License:        NonFree
URL:            http://www.retroarch.com
Source:         %{name}-%{version}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  make

%description
This is yet another Megadrive / Genesis / Sega CD / Mega CD / 32X / SMS
emulator, which was written having ARM-based handheld devices in mind
(such as smartphones and handheld consoles like GP2X and Pandora),
but also runs on non-ARM little-endian hardware too. This package is for
RetroArch/Libretro front-end.

%prep
%setup -q

%build
make -f Makefile.libretro

%install
mkdir -p %{buildroot}%{_libdir}/libretro
cp picodrive_libretro.so %{buildroot}%{_libdir}/libretro

%files
%dir %{_libdir}/libretro
%{_libdir}/libretro/picodrive_libretro.so

%changelog
* Sat Jun 12 2021 i@guoyunhe.me
- Update to version 0~git20210611:
  * Fix minor typo (harmless cast of a buffer to an incorrect type)
  * Add support for RETRO_ENVIRONMENT_SET_CONTENT_INFO_OVERRIDE API extension - enables soft patching of non-CD content
  * move conditional out of loop
  * libretro, fix psp emulation display (RGB instead of BGR)
  * VDP DMA/CPU access timing improvements
  * 68k, synchronize timing in fame and musashi (for debugging)
  * sound, fix ym2612 output volume for keyon and level changes
  * sh2 interpreter, minor improvement for irq handling
  * 32x, minor improvement for poll detection
  * sh2 drc+interpreter, minor improvement for cycle counting
  * 68k, fix timing for BTST #imm,Dn and ADDQ.W #imm,An in fame
  * mcd, optimizations for polling detection
  * Add STATIC_LINKING_LINK
  * Define STATIC_LINKING for emscripten
  * Don't attempt to bake in compat_strcasestr when static linking is defined
  * mcd, improve polling detection
  * mcd, improve polling detection
  * 32x, drc, fix saving SH2 SR in dma
  * Buildfix
  * Cleanup
  * m3u:Fix "last disk index" not loaded correctly
  * Update libretro-common
  * Add support for m3u playlist format
  * core, big endian fix (cart sram detection)
  * mcd, improve polling detection
  * ui, scaling in sdl window mode (ATM hidden)
  * libretro, build change for PS3 (disable drc)
  * mcd, fix timing for irq while polling detected
  * mcd, fix crash when unloading cd while playing audio
  * platform, fix debug hex dump if char type is signed
  * libretro, build changes for ngc/wii/wiiu
  * Fix PSP compilation
  * Update .gitlab-ci.yml
  * improvements for type issues
  * fixes for big endian (mostly mcd)
  * build, fix old dingux audio (disable static linking)wq
  * build, tiny release script improvement
  * build, do arch/fpu settings only for known platforms
  * libretro, fix mmap replacement (content intialized to 0)
  * sh2 drc, debug stuff
  * sh2 drc, fix powerpc cache handling
  * sh2 drc, fix powerpc eabi compatibility
  * platform, debug dump if no disassembler support
  * mcd, add dr_mp3 playback support
  * sh2 drc, debugging fixes
  * 68k, fix musashi support (for debugging only)
  * ui, fix sound filter strength not read from config file
  * sh2 drc, tiny optimization for x86
  * libretro, add input bitmask support
  * ui, fix gmenu2x control files (correct category, add chd to filelist)
  * Update .gitlab-ci.yml
  * libretro, build fix for ngc/wii/wiiu
  * libretro, build fix for ngc/wii/wiiu
  * md, fix irq priority handling for H-int
  * 68k, fix unpredictable instruction in ARM asm
  * 32x, scheduling optimization
  * sh2 drc, fix optimized standard division
  * 32x, draw, avoid some warnings
  * 32x, fix speed regression (wt memory write optimization)
  * 32x, arm asm draw optimization
  * sh2 drc, x86 fix, revert 6f64058 (carry usage in NEGC/DIV1)
  * release 1.98
  * add build script for release
  * build improvements for gph/psp devices
  * make, improve build for devices using (open)dingux
  * make, add legacy dingux and retrofw, make libavcodec optional
  * ui, revised menu
  * update libpicofe
  * libretro, fix missing intialization for renderer
  * Add od-beta
  * libretro, turn of DRC for Apple OSes
  * make, some cleanup, slightly better support for legacy dingux
  * vdp fifo, adjust latency delay
  * attempt for DRC support for newer versions of osx/ios
  * attempt for DRC support for newer versions of osx/ios
  * cleanup for psp
  * sh2 drc, debug stuff
  * sh2 drc, don't use x29 (frame pointer) in arm64 backend
  * sh2 drc, adjust max ld/st offset in arm backend
  * sh2 drc, fix oversize blocks ending with JSR/BSR
  * sh2 drc, x86 backend, optimize move #0 with xor
  * sh2 drc, fix reading from constant memory address
  * Add osx-arm64
  * libretro, build fix for ps2
  * mcd, fix memory leaks
  * switch to libchdr with dr_flac
  * core, libretro fixes for chd support
  * core, chd support
  * Add ios-arm64/tvos-arm64
  * core, chd support
  * ui, revised menu and option handling, added sound filter settings
  * vdp rendering, fix crash for sprites with negative x/y (overlooked commit)
  * vdp rendering, fix crash for sprites with negative x/y
  * core, more on chd support
  * core, groundwork for chd support
  * fixes for big endian support (svp drc, libpicofe update)
  * ui, fix for changing SDL emulation display
  * add big endian platform support
  * preparation for retrofw and legacy opendingux support
  * fixes for platform support for PSP: show fps, notices, CD leds
  * fixes for platform support for PSP
  * fixes and improvements for type issues, part 3
  * ui, fix for SDL emulation display if resolution != 320x240
  * sh2 drc, powerpc fixes for OSX, 32 bit, cache handling
  * cz80, fix flags for OUT[ID]/OT[ID]R
  * gp2x, fix for 8bit fast renderer regression
  * vdp renderer, partial sync 8bit fast ARM asm with C code
  * partially revived platform support for PSP (unfinished), part 4
  * sms, fix 8bit fast renderer
  * 32x, fix BGR565 rendering
  * gp2x, fix to show pico ptr
  * vdp renderer, improvements for 8bit fast
  * ui, fix for gfx save/load menu bg (menubg_src != screen)
  * ui, fix linux handling of 32x renderer
  * update libpicofe
  * partially revived platform support for PSP (unfinished), part 3
  * ui, fix battery display for platforms with screen != menuscreen
  * fix for config save, custom value types not written correctly
  * Prepare repo for new toolchain
  * 32x renderer, fix for render buffers with pitch != line width, some speedup
  * sh2 drc, fix for MIPS EABI
  * partially revived platform support for PSP (unfinished) #2
  * Add generic x86/x86_64 and Aarch64
  * partially revived platform support for PSP (unfinished)
  * Update .gitlab-ci.yml
  * Update .gitlab-ci.yml
  * core, structural cleanup, fixes and improvements for type issues #2
  * fix building for arm arch below armv6 (gp2x, bittboy)
  * core, fixes and improvements for type issues
  * configure, fix for newer gcc
  * fixes for gcc warnings wrt 64 bit platforms
  * Change this
  * sound, improved and optimized reimplementation of libretro lowpass filter
  * Update
  * ui, separate sdl keymaps to avoid warnings with -flto
  * OpenDingux: Add missing compiler flags from standalone makefile
  * Update .gitlab-ci.yml
  * SDL, better handling of 2x overlay mode
  * improve mips disassembler to handle most of N32 code
  * vdp, fix for loading saved gfx state
  * 32x, tentative fix for pad handling
  * 32x, restore old fix for X-men
  * cz80, improve cycle accounting
  * 32x, tiny optimization for memory access
  * mcd, add minimp3 playback support, fix libavcodec playback
  * vdp rendering, fix handling of palettes 0-2 color 14 in sprite drawing
  * vdp, fix for 68k access timing
  * vdp, kludge for z80 access
  * fixes for memory leaks and out of bounds memory access found by ASAN or gcc -flto
  * ui, turn cursor off in SDL (was on by default on GKD)
  * libretro, improve ps2 support, switchable renderers, 32X support w/ DRC
  * libretro, add new good (aka 8bit accurate) renderer, fix 256px mode rendering
  * vdp, add handling of external buffers for fast renderer
  * libretro, fix version string
  * libretro, improve toolchain path handling for GCW0
  * rendering, fix bgr555 output mode
  * drc, fix libretro removing of gcc-only syntax
  * libretro, fix apple os builds
  * libretro, fix handling of zlib
  * make, improve detection of gcc
  * Merge from libretro/master:46902e0 for repo synchronization
  * release 1.97
  * sh2 drc, fix for mapping in register cache
  * mcd, tentative fix for hanging
  * mcd, fix for slave polling detection
  * mcd, fixes for cycle accounting
  * ui, revise status line handling
  * mcd, fix SEEK status reporting
  * switch libpicofe to local repo
  * sh2 drc, fix sh2 reg enum usage
  * sh2 drc, fix PIC function calling for MIPS backend
  * fix key mapping for opendingux platforms
  * fix for config reading of key mappings
  * sh2 drc, fixes for cache handling on arm and mips cpus
  * libpicofe, new version for triple buffering with sdl
  * add a hack for Decap Attack
  * sh2 drc, MIPS cache maintenance optimisation
  * sdl, enable triple buffering
  * sh2 drc, fix for cpu cache handling
  * sdl ui, fix status line artifacts if starting with rom on cmdline
  * sh2 drc, improve T bit propagation
  * sh2 drc, fix for cpu cache handling
  * more rendering fixes and optimisations
  * ui, fix sdl flickering and status lines artifact issues
  * vdp rendering, fix SAT caching for high addresses >64KB
  * vdp rendering, fix fast-forward graphics
  * vdp rendering, layer drawing optimisation
  * vdp rendering, cleanup and optimisation
  * frontend, fix scaling option handling
  * vdp rendering, fixes and optimisations
  * audio, improve YM2413 handling
  * vdp rendering, fix window with mixed prio tiles
  * mcd, GenesisPlusGX bugfix 18fca13,33a43e3: report SEEK status while seeking
  * mcd, fix playing wrong audio track after seek
  * vdp, fix for gfx save/load menu bg
  * vdp rendering, fix sprite masking and interlace layer priority
  * vdp rendering, fix highlight op on shadow
  * arm asm, tiny optimisation for 68k mem access
  * vdp, test code for 8 bit fast renderer
  * update author info
  * sh2 drc, standalone testing tool
  * sh2 drc, fix symbol clash
  * vdp fifo, tentative fix for hanging DMA
  * vdp, optimisation for 8bit renderers
  * SDL UI, fix SDL input and SDL window output mode for osx compile
  * vdp mode 4, optimisation
  * configure, fix for newer gcc
  * adding RG350 platform
  * correcting the treatment of color number 0
  * adding ym2413
  * sms mode 4, fix 8 bit renderer code
  * audio, fix for speed regression after last commit
  * audio, fix sound issues in some intros
  * libretro, build fixes for android
  * sh2 drc, optimize standard division insns (default off, needs more scrutiny)
  * Buildfix
  * Buildfix
  * Fix more conflicting types for prototypes
  * Prevent collission with PS2 SDK
  * Make sure function prototype signatures match, and put typedefs into separate header file
  * libretro, build fixes for ios
  * core, keep offsets header from being build if no preprocessed asm files
  * libretro, build fixes
  * libretro, build fixes
  * core, fix type issues by using stdint types
  * libretro, build fixes
  * sh2, fix for interpreter crash if drc is compiled in too
  * sh2 drc, fix for x86_64 backend
  * libretro, more fixes and cleanups for windows and osx
  * libretro, changes to allow for both standalone and libretro build
  * libretro, fix for windows and osx
  * SDL UI, 2x overlay mode, for improved color resolution
  * switch submodules to github and update to current version
  * libretro make fix for non-arm architectures
  * sh2 drc, fix for SH2 T handling in Mips/RiscV
  * SDL UI, preparation for 2x mode, for improved color resolution
  * sh2 drc, optimisation for SH2 16x16 multiplication
  * SDL UI, fix for CD LED display
  * sh2 drc, backend 32/64 bit compatibility fixes for Mips/RiscV
  * vdp fifo, DMA bugfix
  * sh2 drc, add powerpc64le backend
  * sh2 drc, preparations for powerpc support
  * vdp rendering, bugfix for overlapping high prio sprites
  * release 1.96
  * add copyright stuff to substantially changed files
  * sh2 drc: revised ARM A32 backend optimizer
  * 32x: libretro bugfix
  * sh2: optimisations in drc
  * audio: fix for save/load
  * sh2: bugfix in drc
  * audio: SN76496 fixes
  * 32x poll detection fix
  * vdp fifo, bugfix
  * audio: add option to switch off SSG-EG
  * audio: fixes and optimizations for SSG-EG
  * audio: improve cycle accuracy of SN76496+YM2612
  * 32x, small improvement for poll detection
  * sh2, optimizations to innermost run loop
  * add sh2 ubc area to poll detection
  * 32x pwm, tiny optimization
  * sh2 timer optimization
  * menu background fix for pal mode
  * ym2612 ARM optimisations
  * vdp rendering, sprite caching optimization
  * ym2612 ARM, bug fixing and small optimizations
  * vdp DMA optimizations
  * fix for gp2x audio regression
  * vdp fifo speed optimization
  * fix for 68K cycle accounting
  * vdp rendering fixes
  * vdp rendering, fix for CD (sprites from WORD RAM)
  * ARM asm, symbol visibility fix
  * vdp rendering fixes (debug register, vscroll) for overdrive 2
  * vdp fifo speed optimization
  * hvcounter table resolution reduced
  * vdp rendering improvements
  * draw.c, DrawLayer(): impl. proper linescroll, fixes issue #56
  * vdp rendering, tiny improvement
  * 32x, small improvement for poll detector
  * vdp, some small improvements
  * fix config file parsing for long filenames
  * arm asm sprite rendering: add line accidently deleted in ea431e9
  * ARM SVP drc revived
  * vdp sprite rendering fixes
  * more ARM asm sprite rendering bugfixes
  * improved hi prio sprite rendering speed
  * vdp, tentative fix for save/load compatibility
  * fix for VINT while DMA is running
  * fix for EI insn in cz80 (partial revert of 43e1401)
  * bugfix for ARM asm sprite rendering
  * vdp fifo, refined timing
  * vdp sprite rendering fix
  * vdp fifo, another revision
  * vdp sprite handling improvement (SAT cache)
  * vdp fifo, tentative fix for broken save/load
  * vdp rendering fixes
  * 32X poll detection fix
  * fix compatibility with ancient gas
  * vdp fifo: kludge for DMA fill interrupted by CPU
  * sh2 drc: fix for crash in generated code on x86_64
  * revised VDP fifo implementation
  * new hvcounter tables as per spritesmind.net threads
  * regression fix for gp2x 8bit fast mode
  * improved VRAM128K support (overdrive 2)
  * VDP timing improvements
  * added debug reg sprite plane support (fixes some issues in overdrive 2 demo)
  * sprite rendering improvements for masking and limit edge cases
  * audio fixes for overdrive demo
  * emulator timing fixes, VDP DMA fixes, improved DAC audio
  * bug fixes in drc, audio, display
  * audio: added SSG-EG to YM2612, plus some timing changes for SN76496+YM2612
  * add DC filter to sound mixer to remove potential PCM DC offset
  * sh2 drc: updates from mame for ym2612 sound
  * sh2 drc: optimize T bit handling for A64
  * sh2 drc: fix speed regression
  * sh2 drc: cleanup, fix for drc crash, for mips code emitter
  * deal with some gcc7+ warnings
  * remove textrels with -fPIC/-fPIE (for android/ios)
  * sh2 drc, tentative MIPS32/64 Release 2 support
  * release 1.95
  * sh2 drc: bug fixing
  * sh2 drc: fixed some RISC-V bugs
  * sh2 drc, small improvements and bug fixes for code emitters
  * sh2 drc, improved memory management
  * sh2 drc: RISC-V (RV64IM) code emitter, some work on MIPS64
  * sh2 drc: RISC-V (RV64IM) code emitter, some work on MIPS64
  * sh2 drc: optimizations for MIPS code emitting
  * sh2 drc: moved host register assignment to code emitters, minor bugfixing
  * Remove unused header
  * Only build evdev code on GP2X and Pandora
  * 32x, finetuning
  * fix gp2x regression
  * sh2 drc: reorganised block mgmt code, plus some small scale optimisations
  * sh2 drc: bugfix in block management
  * sh2 drc: bugfix in block management
  * sh2 drc bugfix for aarch64/mips
  * 32x, improved auto frame skip, plus new config option for max auto skip
  * 32x, configurable pwm irq optimization to reduce pwm irq load
  * 32x, speed improvement
  * sh2 drc: speed optimization and bugfixing
  * sh2 drc: fix i386 regression
  * sh2 drc: bug fixing and optimization in register cache and branch handling
  * sh2 drc: drc exit, block linking and branch handling revised (overlooked commit)
  * sh2 drc: drc exit, block linking and branch handling revised
  * sh2 drc: improved RTS call stack cache
  * sh2 drc: rework of register cache to implement basic loop optmization
  * various smallish optimizations, cleanups, and bug fixes
  * cleanup and microoptimizations in SH2 hw handling
  * some drawing code C optimisations
  * bug fix in comm poll fifo, and back to -O3
  * pff... README, 2nd try
  * configuration changes and README
  * cleanup config files, copyright stuff
  * fix for mkoffsets without multiarch binutils
  * various small fixes and optimsations
  * sh2 drc: add aarch64 backend for A64
  * sh2 drc: add mipsel backend for MIPS32 Release 1 (for JZ47xx)
  * SH2 drc: register cache overhaul (bugfixing, speed, readability)
  * SH2 drc: bug fixing and small speed improvements
  * 32X: memory access and polling bug fixes
  * sh2 drc, x86 code emitter: use x86-64 registers R8-R15
  * 32x DMA memory copy performance optimisation
  * sh2 drc, change utils abi to pass sh2 PC in arg0 (reduces compiled code size)
  * sh2 drc, keep T bit in host flags as long as possible
  * add xSR/RTS call stack cache to sh2 drc
  * polling detection: communication poll fifo to avoid comm data loss
  * sh2 memory access improvements, revive ARM asm memory functions
  * sh2 drc, register cache optimisations
  * sh2 drc, block management bugfixes and cleanup
  * sh2 drc, add detection for in-memory polling
  * sh2 drc, add loop detector, handle delay/idle loops
  * sh2 drc, code emitter cleanup, add ARM reorder stage to reduce interlock
  * sh2 drc, make B/W read functions signed (reduces generated code size)
  * sh2 drc, improved constant handling and register allocator
  * speed improvement and fixes for 32x ARM asm draw
  * add literal pool to sh2 drc (for armv[456] without MOVT/W)
  * sh2 drc, reuse blocks if already previously compiled (speedup for Virtua *)
  * various small improvements and fixes
  * overhaul of translation cache and sh2 literals handling
  * added branch cache to sh2 drc to improve cross-tcache jump speed
  * sh2 memory interface optimzations
  * overhaul of the register cache (improves generated code by some 10+%%)
  * debug stuff, bug fixing
  * move saving SH2 SR into memory access and do so only if needed
  * add 32bit memory access functions for SH2
  * sh2 drc: sh2 addr modes generalization, more const propagation, code gen optimizations
  * DRC: reworked scan_block (fix register usage masks, better block and literals detection)
  * minor changes
  * reworked palette and buffer handling due to some 32X bugs
  * revamped 32X draw arm asm code
  * kludges for wwf raw, nfl
  * substituted tool to obtain target structure offsets (for asm)
  * improved sh2 clock handling, bug fixing + small improvement to drc emitters
  * sh2 drc host disassembler integration for gp2x
  * bugfix for 32x
  * bfd-less arm disassembler for gph
  * config for x86 (32 bit only, for SH2 drc), add/revive profiling
  * arm asm memory access functions for m/s68k
  * config templates for gp2x, caanoo, dingux either with system toolchain (open2x,gph,opendingux) or ubuntu arm(gcc 4.7 is highest possible),mips
  * arm asm syntax fixes for open2x
  * make gp2x mp3 playback functional (need to unpack and compile helix decoder separately in platform/common/helix)
  * fix gp2x compilation (using linaro arm gcc 4.7 on ubuntu)
  * release 1.93
  * libretro: Allow setting GIT_VERSION.
  * Makefile: Update one more DEBUG conditional
  * Makefile: Build with optimizations if DEBUG=0
  * ctr/3ds: attempt to improve cache flushing
  * fix some issues with menu bg
  * fix a corner case with h-int
  * fix DrawSpritesHiAS
  * add a header fixup
  * sms: improve irq handling
  * 32x: implement standard/ssf2 mapper, part 2
  * don't spam DMA message
  * 32x: implement standard/ssf2 mapper
* Wed Sep  2 2020 i@guoyunhe.me
- Update to version 0~git20200816:
  * Fix non-MSVC builds
  * Fixed MSVC compilation, VFS
* Sun Aug  9 2020 i@guoyunhe.me
- Update to version 0~git20200716:
  * libretro, build fixes ffor android/ios
  * libretro, tentative fix for android build
  * sh2 drc, optimize standard division insns (default off, needs more scrutiny)
  * Buildfix
  * Buildfix
  * Fix more conflicting types for prototypes
  * Prevent collission with PS2 SDK
  * Make sure function prototype signatures match, and put typedefs into separate header file
  * core, keep offsets header from being build if no preprocessed asm files
  * libretro, build fixes
  * libretro, build fixes
  * core, fix type issues by using stdint types
  * libretro, build fixes
  * sh2, fix for interpreter crash if drc is compiled in too
  * sh2 drc, fix for x86_64 backend
  * libretro, more fixes and cleanups for windows and osx
  * libretro, fix for windows and osx
  * libretro, changes to allow for both standalone and libretro build
  * SDL UI, 2x overlay mode, for improved color resolution
  * libretro make fix for non-arm architectures
  * sh2 drc, fix for SH2 T handling in Mips/RiscV
  * SDL UI, preparation for 2x mode, for improved color resolution
  * sh2 drc, optimisation for SH2 16x16 multiplication
  * SDL UI, fix for CD LED display
  * sh2 drc, backend 32/64 bit compatibility fixes for Mips/RiscV
  * vdp fifo, DMA bugfix
  * sh2 drc, add powerpc64le backend
  * sh2 drc, preparations for powerpc support
  * vdp rendering, bugfix for overlapping high prio sprites
  * release 1.96
  * add copyright stuff to substantially changed files
  * sh2 drc: revised ARM A32 backend optimizer
  * 32x: libretro bugfix
  * sh2: optimisations in drc
  * audio: fix for save/load
  * sh2: bugfix in drc
  * audio: SN76496 fixes
  * 32x poll detection fix
  * vdp fifo, bugfix
  * audio: add option to switch off SSG-EG
  * audio: fixes and optimizations for SSG-EG
  * audio: improve cycle accuracy of SN76496+YM2612
  * 32x, small improvement for poll detection
  * sh2, optimizations to innermost run loop
  * add sh2 ubc area to poll detection
  * 32x pwm, tiny optimization
  * sh2 timer optimization
  * menu background fix for pal mode
  * ym2612 ARM optimisations
  * vdp rendering, sprite caching optimization
  * ym2612 ARM, bug fixing and small optimizations
  * vdp DMA optimizations
  * fix for gp2x audio regression
  * vdp fifo speed optimization
  * fix for 68K cycle accounting
  * vdp rendering fixes
  * vdp rendering, fix for CD (sprites from WORD RAM)
  * ARM asm, symbol visibility fix
  * vdp rendering fixes (debug register, vscroll) for overdrive 2
  * vdp fifo speed optimization
  * hvcounter table resolution reduced
  * vdp rendering improvements
  * vdp rendering, tiny improvement
  * 32x, small improvement for poll detector
  * vdp, some small improvements
  * fix config file parsing for long filenames
  * arm asm sprite rendering: add line accidently deleted in ea431e9
  * ARM SVP drc revived
  * vdp sprite rendering fixes
  * more ARM asm sprite rendering bugfixes
  * improved hi prio sprite rendering speed
  * vdp, tentative fix for save/load compatibility
  * fix for VINT while DMA is running
  * fix for EI insn in cz80 (partial revert of 43e1401)
  * bugfix for ARM asm sprite rendering
  * vdp fifo, refined timing
  * vdp sprite rendering fix
  * vdp fifo, another revision
  * vdp sprite handling improvement (SAT cache)
  * vdp fifo, tentative fix for broken save/load
  * vdp rendering fixes
  * 32X poll detection fix
  * fix compatibility with ancient gas
  * vdp fifo: kludge for DMA fill interrupted by CPU
  * sh2 drc: fix for crash in generated code on x86_64
  * revised VDP fifo implementation
  * new hvcounter tables as per spritesmind.net threads
  * regression fix for gp2x 8bit fast mode
  * improved VRAM128K support (overdrive 2)
  * VDP timing improvements
  * added debug reg sprite plane support (fixes some issues in overdrive 2 demo)
  * sprite rendering improvements for masking and limit edge cases
  * audio fixes for overdrive demo
  * emulator timing fixes, VDP DMA fixes, improved DAC audio
  * bug fixes in drc, audio, display
  * audio: added SSG-EG to YM2612, plus some timing changes for SN76496+YM2612
  * add DC filter to sound mixer to remove potential PCM DC offset
  * sh2 drc: updates from mame for ym2612 sound
  * sh2 drc: optimize T bit handling for A64
  * sh2 drc: fix speed regression
  * sh2 drc: cleanup, fix for drc crash, for mips code emitter
  * remove textrels with -fPIC/-fPIE (for android/ios)
  * sh2 drc, tentative MIPS32/64 Release 2 support
  * release 1.95
  * sh2 drc: bug fixing
  * sh2 drc: fixed some RISC-V bugs
  * sh2 drc, small improvements and bug fixes for code emitters
  * sh2 drc, improved memory management
  * sh2 drc: RISC-V (RV64IM) code emitter, some work on MIPS64
  * sh2 drc: RISC-V (RV64IM) code emitter, some work on MIPS64
  * sh2 drc: optimizations for MIPS code emitting
  * sh2 drc: moved host register assignment to code emitters, minor bugfixing
  * 32x, finetuning
  * fix gp2x regression
  * sh2 drc: reorganised block mgmt code, plus some small scale optimisations
  * sh2 drc: bugfix in block management
  * sh2 drc: bugfix in block management
  * sh2 drc bugfix for aarch64/mips
  * 32x, improved auto frame skip, plus new config option for max auto skip
  * 32x, configurable pwm irq optimization to reduce pwm irq load
  * 32x, speed improvement
  * sh2 drc: speed optimization and bugfixing
  * sh2 drc: fix i386 regression
  * sh2 drc: bug fixing and optimization in register cache and branch handling
  * sh2 drc: drc exit, block linking and branch handling revised (overlooked commit)
  * sh2 drc: drc exit, block linking and branch handling revised
  * sh2 drc: improved RTS call stack cache
  * sh2 drc: rework of register cache to implement basic loop optmization
  * various smallish optimizations, cleanups, and bug fixes
  * cleanup and microoptimizations in SH2 hw handling
  * some drawing code C optimisations
  * bug fix in comm poll fifo, and back to -O3
  * pff... README, 2nd try
  * configuration changes and README
  * cleanup config files, copyright stuff
  * fix for mkoffsets without multiarch binutils
  * various small fixes and optimsations
  * sh2 drc: add aarch64 backend for A64
  * sh2 drc: add mipsel backend for MIPS32 Release 1 (for JZ47xx)
  * SH2 drc: register cache overhaul (bugfixing, speed, readability)
  * SH2 drc: bug fixing and small speed improvements
  * 32X: memory access and polling bug fixes
  * sh2 drc, x86 code emitter: use x86-64 registers R8-R15
  * 32x DMA memory copy performance optimisation
  * sh2 drc, change utils abi to pass sh2 PC in arg0 (reduces compiled code size)
  * sh2 drc, keep T bit in host flags as long as possible
  * add xSR/RTS call stack cache to sh2 drc
  * polling detection: communication poll fifo to avoid comm data loss
  * sh2 memory access improvements, revive ARM asm memory functions
  * sh2 drc, register cache optimisations
  * sh2 drc, block management bugfixes and cleanup
  * sh2 drc, add detection for in-memory polling
  * sh2 drc, add loop detector, handle delay/idle loops
  * sh2 drc, code emitter cleanup, add ARM reorder stage to reduce interlock
  * sh2 drc, make B/W read functions signed (reduces generated code size)
  * sh2 drc, improved constant handling and register allocator
  * speed improvement and fixes for 32x ARM asm draw
  * add literal pool to sh2 drc (for armv[456] without MOVT/W)
  * sh2 drc, reuse blocks if already previously compiled (speedup for Virtua *)
  * various small improvements and fixes
  * overhaul of translation cache and sh2 literals handling
  * added branch cache to sh2 drc to improve cross-tcache jump speed
  * sh2 memory interface optimzations
  * overhaul of the register cache (improves generated code by some 10+%%)
  * debug stuff, bug fixing
  * move saving SH2 SR into memory access and do so only if needed
  * add 32bit memory access functions for SH2
  * sh2 drc: sh2 addr modes generalization, more const propagation, code gen optimizations
  * DRC: reworked scan_block (fix register usage masks, better block and literals detection)
  * minor changes
  * reworked palette and buffer handling due to some 32X bugs
  * revamped 32X draw arm asm code
  * kludges for wwf raw, nfl
  * substituted tool to obtain target structure offsets (for asm)
  * improved sh2 clock handling, bug fixing + small improvement to drc emitters
  * sh2 drc host disassembler integration for gp2x
  * bugfix for 32x
  * bfd-less arm disassembler for gph
  * config for x86 (32 bit only, for SH2 drc), add/revive profiling
  * arm asm memory access functions for m/s68k
  * config templates for gp2x, caanoo, dingux either with system toolchain (open2x,gph,opendingux) or ubuntu arm(gcc 4.7 is highest possible),mips
  * arm asm syntax fixes for open2x
  * make gp2x mp3 playback functional (need to unpack and compile helix decoder separately in platform/common/helix)
  * fix gp2x compilation (using linaro arm gcc 4.7 on ubuntu)
  * release 1.93
  * libretro: Allow setting GIT_VERSION.
  * Makefile: Build with optimizations if DEBUG=0
  * Remove not longer files in Picodrive for PS2
  * Change GSKit PS2 version
  * Update picodrive
  * Define HAVE_NO_LANGEXTRA
  * Adapt to newlib
  * Add option to change sound quality
  * Copy tile-based fast renderer buffer
  * Add option to change renderer
* Mon Feb 10 2020 Guo Yunhe <i@guoyunhe.me>
- Initial version
